@@ -181,35 +181,62 @@ class NamespaceDataAccessManager:
     
     async def get_namespace_config(self, namespace_name: str) -> dict:
         """从任务中心API获取命名空间配置"""
-        url = f"{self.task_center_base_url}/api/namespaces/{namespace_name}"
-        
+        # 直接从数据库获取，而不是通过HTTP调用自己
+        # 这避免了循环依赖和网络问题
         try:
-            session = await self._get_session()
-            async with session.get(url) as resp:
-                if resp.status == 200:
-                    data = await resp.json()
-                    # API返回的是redis_config和pg_config，直接使用
-                    redis_config = data.get('redis_config', {})
-                    pg_config = data.get('pg_config', {})
-                    
-                    # 兼容旧格式：如果有redis_url和pg_url字段
-                    if not redis_config and data.get('redis_url'):
-                        redis_config = {'url': data.get('redis_url')}
-                    
-                    if not pg_config and data.get('pg_url'):
-                        pg_config = {'url': data.get('pg_url')}
-                    
+            # 先尝试从缓存或直接数据库访问
+            from jettask.webui.backend.models import NamespaceModel
+            from jettask.webui.backend.db_init import get_async_session
+            from sqlalchemy import select
+            
+            async with get_async_session() as session:
+                stmt = select(NamespaceModel).where(NamespaceModel.name == namespace_name)
+                result = await session.execute(stmt)
+                namespace = result.scalar_one_or_none()
+                
+                if namespace:
                     return {
-                        'name': data.get('name'),
-                        'redis_config': redis_config,
-                        'pg_config': pg_config
+                        'name': namespace.name,
+                        'redis_config': namespace.redis_config or {},
+                        'pg_config': namespace.pg_config or {}
                     }
                 else:
-                    raise ValueError(f"无法获取命名空间 {namespace_name} 的配置: HTTP {resp.status}")
-        except Exception as e:
-            logger.error(f"获取命名空间 {namespace_name} 配置失败: {e}")
-            traceback.print_exc()
-            raise
+                    raise ValueError(f"命名空间 {namespace_name} 不存在")
+        except (ImportError, Exception) as e:
+            # 如果无法直接访问数据库，则通过HTTP调用（但使用127.0.0.1）
+            logger.warning(f"直接数据库访问失败，回退到HTTP调用: {e}")
+            base_url = self.task_center_base_url
+            if 'localhost' in base_url:
+                base_url = base_url.replace('localhost', '127.0.0.1')
+            url = f"{base_url}/api/namespaces/{namespace_name}"
+            
+            try:
+                session = await self._get_session()
+                async with session.get(url) as resp:
+                    if resp.status == 200:
+                        data = await resp.json()
+                        # API返回的是redis_config和pg_config，直接使用
+                        redis_config = data.get('redis_config', {})
+                        pg_config = data.get('pg_config', {})
+                        
+                        # 兼容旧格式：如果有redis_url和pg_url字段
+                        if not redis_config and data.get('redis_url'):
+                            redis_config = {'url': data.get('redis_url')}
+                        
+                        if not pg_config and data.get('pg_url'):
+                            pg_config = {'url': data.get('pg_url')}
+                        
+                        return {
+                            'name': data.get('name'),
+                            'redis_config': redis_config,
+                            'pg_config': pg_config
+                        }
+                    else:
+                        raise ValueError(f"无法获取命名空间 {namespace_name} 的配置: HTTP {resp.status}")
+            except Exception as e:
+                logger.error(f"通过HTTP获取命名空间 {namespace_name} 配置失败: {e}")
+                traceback.print_exc()
+                raise
     
     async def get_connection(self, namespace_name: str) -> NamespaceConnection:
         """
