@@ -7,6 +7,8 @@ import 'dayjs/locale/zh-cn'
 import App from './App'
 import './index.css'
 import './utils/suppressWarnings'
+// 初始化 API 配置（必须在其他组件之前）
+import './services/api'
 
 // 设置 dayjs 为中文
 dayjs.locale('zh-cn')
