@@ -102,8 +102,9 @@ function ScheduledTasks() {
         offset: (params.current - 1) * params.pageSize,
       };
 
+      const apiBase = window.JETTASK_API_URL || 'http://localhost:8001';
       const response = await axios.get(
-        `http://localhost:8001/api/data/scheduled-tasks/${currentNamespace}`,
+        `${apiBase}/api/data/scheduled-tasks/${currentNamespace}`,
         { params: requestParams }
       );
 
