@@ -161,7 +161,8 @@ function Settings() {
         refreshNamespaceList();  // 触发全局命名空间列表刷新
         
         // 显示连接URL
-        const fullUrl = `http://localhost:8001${response.data.connection_url}`;
+        const apiBase = window.JETTASK_API_URL || 'http://localhost:8001';
+        const fullUrl = `${apiBase}${response.data.connection_url}`;
         Modal.success({
           title: '命名空间创建成功',
           content: (
